Analyser si la couverture est positive, négative ou neutre sur plusieurs dimensions, filtrée par source
Vérifiez si la couverture de plusieurs organisations est positive, négative ou neutre, en filtrant par des sources de haute qualité et par plage de dates
Paramètres d'entrée
| Paramètre | Description | Type | Valeur par défaut | Requis |
|---|---|---|---|---|
| sentiment.overall.score.min | Score de sentiment minimum (0.5 = modérément positif) | float | Oui | |
| category.id | Filtre de catégorie. | string | Oui | |
| organization.name | Plusieurs organisations (séparées par des virgules). | string | Oui | |
| sort.by | Trier par score de sentiment. | string | Oui | |
| sort.order | Ordre décroissant. | string | Oui | |
| api_key | Votre clé API | string | Oui | |
| per_page | Nombre maximum d'articles à récupérer | integer | 20 | Non |
Exemples de flux de travail
Vérifiez si la couverture est positive, négative ou neutre dans plusieurs dimensions :
curl -X GET "https://api.apitube.io/v1/news/everything?sentiment.overall.score.min=0.5&category.id=medtop:04000000&organization.name=Tesla,Google&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Comparez si la couverture est positive, négative ou neutre sur différents marchés :
curl -X GET "https://api.apitube.io/v1/news/everything?sentiment.overall.polarity=negative&source.country.code=us,gb,de&category.id=medtop:07000000&published_at.start=2023-01-01&published_at.end=2023-12-31&api_key=YOUR_API_KEY"
Comparez le ton de la couverture entre les types de sources :
curl -X GET "https://api.apitube.io/v1/news/everything?title=climate%20change&sentiment.overall.score.min=0.6&published_at.start=2023-01-01&published_at.end=2023-01-31&api_key=YOUR_API_KEY"
Exemples connexes
- Trouvez des articles où le ton du titre diffère du ton de l'article
- Obtenir des actualités sur un ton positif
- Obtenez des articles sur Elon Musk avec un ton positif
- Suivez vos concurrents
- Triez par score d'engagement
Recette pour cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?sentiment.overall.score.min=0.5&category.id=medtop%3A04000000&organization.name=Tesla%2CGoogle&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY&per_page=20' \
--header 'Content-Type: application/json'
Recette pour Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"sentiment.overall.score.min": 0.5,
"category.id": "medtop:04000000",
"organization.name": "Tesla,Google",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"api_key": "YOUR_API_KEY",
"per_page": 20
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Recette pour Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"sentiment.overall.score.min": 0.5,
"category.id": "medtop:04000000",
"organization.name": "Tesla,Google",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"api_key": "YOUR_API_KEY",
"per_page": 20
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Recette pour PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'sentiment.overall.score.min' => 0.5,
'category.id' => 'medtop:04000000',
'organization.name' => 'Tesla,Google',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'api_key' => 'YOUR_API_KEY',
'per_page' => 20,
],
]);
echo $response->getBody();
Recette pour Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?sentiment.overall.score.min=0.5&category.id=medtop%3A04000000&organization.name=Tesla%2CGoogle&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY&per_page=20")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();